Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1810)

Unified Diff: tests/dartino_tests/multiprogram_tests.dart

Issue 1659163007: Rename fletch -> dartino (Closed) Base URL: https://github.com/dartino/sdk.git@master
Patch Set: address comments Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tests/dartino_tests/messages.dart ('k') | tests/dartino_tests/self_tests.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tests/dartino_tests/multiprogram_tests.dart
diff --git a/tests/fletch_tests/multiprogram_tests.dart b/tests/dartino_tests/multiprogram_tests.dart
similarity index 97%
rename from tests/fletch_tests/multiprogram_tests.dart
rename to tests/dartino_tests/multiprogram_tests.dart
index c1b2e0970ed30bdbd4820837b31b62f133c04a80..471034aceb8f8720ff256b7804c18247638deaee 100644
--- a/tests/fletch_tests/multiprogram_tests.dart
+++ b/tests/dartino_tests/multiprogram_tests.dart
@@ -13,7 +13,7 @@ import 'dart:io' show
import 'package:expect/expect.dart' show
Expect;
-import '../fletchc/run.dart' show
+import '../dartino_compiler/run.dart' show
export;
import 'utils.dart' show
@@ -119,7 +119,7 @@ Future runTest(String mode, List testNamesWithExitCodes, {int duplicate}) {
..add(mode)
..addAll(snapshotsExitcodeTuples);
// Run all the snapshots inside one fletch vm.
print("Running $multiprogramRunner ${arguments.join(' ')}");
ProcessResult result = await Process.run(multiprogramRunner, arguments);
print("Done running $multiprogramRunner ${arguments.join(' ')}:");
@@ -119,7 +119,7 @@ Future runTest(String mode, List testNamesWithExitCodes, {int duplicate}) {
..add(mode)
..addAll(snapshotsExitcodeTuples);
- // Run all the snapshots inside one fletch vm.
+ // Run all the snapshots inside one dartino vm.
print("Running $multiprogramRunner ${arguments.join(' ')}");
ProcessResult result = await Process.run(multiprogramRunner, arguments);
« no previous file with comments | « tests/dartino_tests/messages.dart ('k') | tests/dartino_tests/self_tests.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698